@@ -135,14 +135,14 @@ def update_database_on_remote():
     run("rm -f /tmp/%(DB_USER)s.sql" % wp_config['remote'])
 
 
-def deploy():
+def deploy(revision="master"):
     require('base_dir', provided_by=("env_test", "env_live"),
             used_for='defining the deploy environment')
 
     deploy_archive_dir = tempfile.mkdtemp()
 
     with lcd(env.local_base_dir):
-        local('git archive master %s | tar -x -f- -C %s' % (env.local_wordpress_path, deploy_archive_dir))
+        local('git archive %s %s | tar -x -f- -C %s' % (revision, env.local_wordpress_path, deploy_archive_dir))
 
     local('rsync -a --exclude wp-config.php --exclude wp-content/uploads/* %s/%s/* %s@%s:%s/%s' %
           (deploy_archive_dir, env.local_wordpress_path, env.user, env.host,
